﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Text;
using System.Windows.Media;
using System.Windows.Media.Imaging;

namespace ImageViewer
{
    /// <summary>
    /// Represents bitmap images residing at a specific file path.
    /// </summary>
	public class DirectoryImageList
	{
		private string _path;
		private List<BitmapSource> _images = new List<BitmapSource>();

		public DirectoryImageList(string path)
		{
			_path = path;
			LoadImages();
		}

        /// <summary>
        /// Gets a List<BitmapSource> object of all of the images found at the location specified by Path.
        /// </summary>
		public List<BitmapSource> Images
		{
            get { return _images; }
		}

        /// <summary>
        /// Gets/sets the path to the file folder containing the desired images.
        /// </summary>
		public string Path
		{
			get { return _path; }
			set 
			{ 
				_path = value;
				LoadImages();		
			}
		}

        /// <summary>
        /// Examines the folder path for valid image files, and sets the _images object appropriately.
        /// </summary>
		private void LoadImages()
		{
			_images.Clear();
			BitmapImage img;

			foreach (string file in Directory.GetFiles(_path))
			{
				try
				{
					img = new BitmapImage(new Uri(file));
					
					_images.Add(img);

				}
				catch
				{
					// empty catch; ignore any files that won't load as
					// an image...
				}


			}

		}

	}
}
